@@ -33,7 +33,7 @@
 
 fan.beam  <- function(alpha, dalpha,  orientation = c(0,0,1,1,0,0), 
                       origin = c(0,0,0),
-                      ref.pseudo = "", 
+                      ref.pseudo = "ref1", 
                       frame.of.reference = "",
                       alias = "", 
                       description = "beam fan"){
